==> hermes-0.2.9.zip: hermes/content/hermes.js <==
//Below basic
// switch to visibility rather than display by Azrael

var lastShown;
var mozHermes;

function load()
{
  mozHermes=document.getElementById("mozhermes");
  lastShown="blank";
}

function Show(select){
  if (lastShown.length>0)
  {
    // var hideme=document.getElementById(lastShown);

    // add parentNode for workaround mozilla bug 86633
    var hideme=document.getElementById(lastShown).parentNode;

    hideme.style.visibility="hidden";
  }

  //var id = select.options.item(select.selectedIndex).value;
var id=select.value // from DrBrain

  // changes size of hermes image
  mozHermes.style.width = id != "blank" ? "40px" : "auto";

  //var showme = document.getElementById(id);

  // add parentNode for workaround mozilla bug 86633
  var showme = document.getElementById(id).parentNode;

  showme.style.visibility= "visible";
  lastShown = id;
}


function searchclear(login,value){

  if (login.value==value){
    login.value='';
  }
  else if(login.value==''){
    login.value=value;
  }
}

function yahooSecure( checkbox )
{
    
    var form = document.getElementById("yahoo");
    if( checkbox.checked )
        form.action = "https://edit.yes.yahoo.com/config/login";
    else
        form.action = "http://edit.yes.yahoo.com/config/login";
}
/*
  signout with international/language support
  'url' is the url for signout
  'id' is the id to select which region/language
  ('id' can be '' if there is no language/international support)
*/
function signout(url,id)
{
    var select = id==''? '': document.getElementById(id);
    var value = select==''? '': select.options.item(select.selectedIndex).value;
    window.open( url + value,"_content");
}

//Above basic

function gotoHermes(){
    var hermes = window.open('http://hermes.mozdev.org', '_content');
}

function gotoBug104633(){
    var hermes = window.open('http://bugzilla.mozilla.org/show_bug.cgi?id=104633', '_content');
}

// since we are using chrome this isn't useful except for debugging
function refreshHermes(){
    window.location.reload(true);
}

==> hermes-0.2.13.zip: hermes/content/hermes.js <==
//Below basic
// switch to visibility rather than display by Azrael

var lastShown;
var mozHermes;

function load()
{
  mozHermes=document.getElementById("mozhermes");
  lastShown="blank";
}

function Show(select){
  if (lastShown.length>0)
  {
    // var hideme=document.getElementById(lastShown);

    // add parentNode for workaround mozilla bug 86633
    var hideme=document.getElementById(lastShown).parentNode;

    hideme.style.visibility="hidden";
  }

  //var id = select.options.item(select.selectedIndex).value;
var id=select.value // from DrBrain

  // changes size of hermes image
  mozHermes.style.width = id != "blank" ? "40px" : "auto";

  //var showme = document.getElementById(id);

  // add parentNode for workaround mozilla bug 86633
  var showme = document.getElementById(id).parentNode;

  showme.style.visibility= "visible";
  lastShown = id;
}

function changecolor(what,which){

  what.style.color=which;
  
}


function searchclear(login,value){

  if (login.value==value){
    login.value='';
  }
  else if(login.value==''){
    login.value=value;
  }
}

function yahooSecure( checkbox )
{
    
    var form = document.getElementById("yahoo");
    if( checkbox.checked )
        form.action = "https://login.yahoo.com/config/login";
    else
        form.action = "http://login.yahoo.com/config/login";
}
/*
  signout with international/language support
  'url' is the url for signout
  'id' is the id to select which region/language
  ('id' can be '' if there is no language/international support)
*/
function signout(url,id)
{
    var select = id==''? '': document.getElementById(id);
    var value = select==''? '': select.options.item(select.selectedIndex).value;
    window.open( url + value,"_content");
}

//Above basic

function gotoHermes(){
    var hermes = window.open('http://hermes.mozdev.org', '_content');
}

function gotoBug104633(){
    var hermes = window.open('http://bugzilla.mozilla.org/show_bug.cgi?id=104633', '_content');
}

// since we are using chrome this isn't useful except for debugging
function refreshHermes(){
    window.location.reload(true);
}
